@@ -2,7 +2,8 @@
 
 Text::NSP::Measures::2D::MI - Perl module that provides error checks
                               for Loglieklihood, Total Mutual
-                              Information, Pointwise Mutual Information.
+                              Information, Pointwise Mutual Information
+                              and Poisson-Stirling Measure.
 
 =head1 SYNOPSIS
 
@@ -79,7 +80,7 @@ our ($VERSION, @ISA);
 
 @ISA = qw(Text::NSP::Measures::2D);
 
-$VERSION = '0.93';
+$VERSION = '0.95';
 
 
 =item calculateStatistic() - This method calls the
@@ -245,7 +246,7 @@ Saiyam Kohli,                University of Minnesota Duluth
 
 =head1 HISTORY
 
-Last updated: $Id: MI.pm,v 1.19 2006/06/15 16:53:03 saiyam_kohli Exp $
+Last updated: $Id: MI.pm,v 1.20 2006/06/17 18:03:19 saiyam_kohli Exp $
 
 =head1 BUGS
 
